@@ -1,5 +1,4 @@
 from __future__ import absolute_import
-from __future__ import print_function
 
 import contextlib
 import hmac
@@ -12,14 +11,15 @@ from hashlib import sha1
 import requests
 from builtins import bytes
 
-from .base import Provider as BaseProvider
+from lexicon.providers.base import Provider as BaseProvider
 
 logger = logging.getLogger(__name__)
 
+NAMESERVER_DOMAINS = ['dnsmadeeasy']
 
 def ProviderParser(subparser):
-    subparser.add_argument("--auth-username", help="specify username used to authenticate")
-    subparser.add_argument("--auth-token", help="specify token used authenticate=")
+    subparser.add_argument("--auth-username", help="specify username for authentication")
+    subparser.add_argument("--auth-token", help="specify token for authentication")
 
 class Provider(BaseProvider):
 
@@ -56,12 +56,12 @@ class Provider(BaseProvider):
         try:
             payload = self._post('/dns/managed/{0}/records/'.format(self.domain_id), record)
         except requests.exceptions.HTTPError as e:
-            if e.response.status_code == 400:
-                payload = {}
+            if e.response.status_code != 400:
+                raise
 
                 # http 400 is ok here, because the record probably already exists
         logger.debug('create_record: %s', 'name' in payload)
-        return 'name' in payload
+        return True
 
     # List all records. Return an empty list if no records found
     # type, name and content are used to filter records.
@@ -87,6 +87,9 @@ class Provider(BaseProvider):
             processed_record = self._clean_TXT_record(processed_record)
             records.append(processed_record)
 
+        if content:
+            records = [record for record in records if record['content'].lower() == content.lower()]
+
         logger.debug('list_records: %s', records)
         return records
 
@@ -113,14 +116,17 @@ class Provider(BaseProvider):
     # Delete an existing record.
     # If record does not exist, do nothing.
     def delete_record(self, identifier=None, type=None, name=None, content=None):
+        delete_record_id = []
         if not identifier:
             records = self.list_records(type, name, content)
-            logger.debug('records: %s', records)
-            if len(records) == 1:
-                identifier = records[0]['id']
-            else:
-                raise Exception('Record identifier could not be found.')
-        payload = self._delete('/dns/managed/{0}/records/{1}'.format(self.domain_id, identifier))
+            delete_record_id = [record['id'] for record in records]
+        else:
+            delete_record_id.append(identifier)
+        
+        logger.debug('delete_records: %s', delete_record_id)
+        
+        for record_id in delete_record_id:
+            payload = self._delete('/dns/managed/{0}/records/{1}'.format(self.domain_id, record_id))
 
         # is always True at this point, if a non 200 response is returned an error is raised.
         logger.debug('delete_record: %s', True)
