@@ -1,19 +1,19 @@
 from __future__ import absolute_import
-from __future__ import print_function
 
 import json
 import logging
 
 import requests
 
-from .base import Provider as BaseProvider
+from lexicon.providers.base import Provider as BaseProvider
 
 logger = logging.getLogger(__name__)
 
+NAMESERVER_DOMAINS = ['pointhq.com']
 
 def ProviderParser(subparser):
-    subparser.add_argument("--auth-username", help="specify email address used to authenticate")
-    subparser.add_argument("--auth-token", help="specify token used authenticate")
+    subparser.add_argument("--auth-username", help="specify email address for authentication")
+    subparser.add_argument("--auth-token", help="specify token for authentication")
 
 class Provider(BaseProvider):
 
